@@ -16,6 +16,7 @@
 #include "minigames/cartwheelwindow.h"
 #include "minigames/portholeswindow.h"
 #include "bookinfowindow.h"
+#include "inputnumberwindow.h"
 #include "core/books.h"
 #include "commonstatic.h"
 
@@ -138,9 +139,11 @@ BookWindow::BookWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
+#ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     CommonStatic::CenterWindow(this);
 #endif 
+#endif
 
     m_Settings = CommonStatic::GeneralSettings(this);
     QString font = m_Settings->value("font", "").toString();
@@ -507,14 +510,19 @@ void BookWindow::ChoiceSlot()
 
 void BookWindow::FightSlot()
 {
+#ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     hide();
 #endif
+#endif
+
     bool evaded = false;
     foreach(Enemy* e, m_Section->Enemies){
         FightWindow* dlg = new FightWindow(this, m_Player, e, e->CanBeEvaded, &m_Engine);
+#ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
         dlg->setParent(NULL);
+#endif
 #endif
         dlg->exec();
         evaded = dlg->HasEvaded();
@@ -852,11 +860,19 @@ bool BookWindow::Load(QString filename)
         var = settings.value("item");
         if (var.isValid()){
             Item* i = new Item(var.value<Item>());
+            // For compatibility with previously saved positions, check if the item has
+            // the CanBeEquipped property
+            if ((i->GetIsArmor() || i->GetIsWeapon()) && i->GetProperty("CanBeEquipped").isEmpty())
+                i->SetCanBeEquipped(true);
             m_Player->Items.append(i);
         }else{
             var = settings.value("weapon");
             if (var.isValid()){
-                Weapon* w = new Weapon(var.value<Weapon>());
+                Weapon* w = new Weapon(var.value<Weapon>());                
+                // For compatibility with previously saved positions, check if the weapon has
+                // the CanBeEquipped property
+                if (w->GetProperty("CanBeEquipped").isEmpty())
+                    w->SetCanBeEquipped(true);
                 m_Player->Items.append(w);
             }
         }
@@ -952,8 +968,8 @@ QString BookWindow::ChooseSpecialItem(QString title)
 bool BookWindow::LoadNextBook()
 {
     int bookNumber = m_Book->Number + 1;
-    m_Book = new Book(this);
-    if (!m_Book->Load(Books::GetBookFilename(bookNumber))){
+    Book* book = new Book(this);
+    if (!book->Load(Books::GetBookFilename(bookNumber))){
         QMessageBox msgBox(this);
         msgBox.setWindowTitle(QString("Error loading book"));
 
@@ -961,9 +977,11 @@ bool BookWindow::LoadNextBook()
         msgBox.setText(QString("Error loading book:\n%1").arg(Books::GetBookFilename(bookNumber)));
         msgBox.exec();
 
-        m_Book = NULL;
+        delete book;
+        book = NULL;
         return false;
     }
+    m_Book = book;
     LoadBookFunctions();
     return true;
 }
@@ -1174,3 +1192,10 @@ void BookWindow::SetVisibleChoiceButtons(int number)
         }
     }
 }
+
+int BookWindow::InputNumber(QString title, int min, int max)
+{
+    InputNumberWindow* dlg = new InputNumberWindow(this, title, min, max);
+    dlg->exec();
+    return dlg->GetValue();
+}
