@@ -34,7 +34,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
     Books* books = new Books(this);
     books->LoadList();
-    ui->pbnNew->setEnabled(books->List.count() > 0);
+    ui->pbnNew->setEnabled(books->BookExist(1));
     delete books;
 }
 
@@ -60,8 +60,8 @@ void MainWindow::LoadSlot()
     BookWindow* w = new BookWindow(this);
     w->Init();
 
-#if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
 #ifndef Q_WS_MAEMO_5
+#if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     setVisible(false);
     connect(w, SIGNAL(destroyed()), this, SLOT(BookwindowClosedSlot()));
     w->setParent(NULL);
@@ -129,7 +129,7 @@ void MainWindow::BookwindowClosedSlot()
 
     Books* books = new Books(this);
     books->LoadList();
-    ui->pbnNew->setEnabled(books->List.count() > 0);
+    ui->pbnNew->setEnabled(books->BookExist(1));
     delete books;
 }
 
@@ -149,8 +149,8 @@ void MainWindow::BooksSlot()
 
     BooksWindow* w = new BooksWindow(this);
 
-#if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
 #ifndef Q_WS_MAEMO_5
+#if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     setVisible(false);
     connect(w, SIGNAL(destroyed()), this, SLOT(BookwindowClosedSlot()));
     w->setParent(NULL);
