@@ -12,9 +12,11 @@ StatusWindow::StatusWindow(QWidget *parent, int serie, Player* player, Section*
     ui(new Ui::StatusWindow)
 {
     ui->setupUi(this);
+#ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
     CommonStatic::CenterWindow(this);
 #endif
+#endif
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
@@ -122,11 +124,18 @@ void StatusWindow::ShowData()
     if (weapons.count() > 0){
         ui->lblWeapon1->setText(weapons.at(0)->Name);
         ui->pbnDropWeapon1->setEnabled(true);
-        ui->pbnEquip1->setEnabled(true);
-        if (weapons.at(0)->GetIsEquipped())
+        ui->pbnEquip1->setEnabled(weapons.at(0)->GetCanBeEquipped());
+        if (weapons.at(0)->GetIsEquipped()){
             ui->pbnEquip1->setText("Unequip");
-        else
+#ifdef Q_WS_MAEMO_5
+            ui->pbnEquip1->setFixedWidth(120);
+#endif
+        }else{
             ui->pbnEquip1->setText("Equip");
+#ifdef Q_WS_MAEMO_5
+            ui->pbnEquip1->setFixedWidth(75);
+#endif
+        }
     }else{
         ui->lblWeapon1->setText("-");
     }
@@ -134,11 +143,18 @@ void StatusWindow::ShowData()
     if (weapons.count() > 1){
         ui->lblWeapon2->setText(weapons.at(1)->Name);
         ui->pbnDropWeapon2->setEnabled(true);
-        ui->pbnEquip2->setEnabled(true);
-        if (weapons.at(1)->GetIsEquipped())
+        ui->pbnEquip2->setEnabled(weapons.at(1)->GetCanBeEquipped());
+        if (weapons.at(1)->GetIsEquipped()){
             ui->pbnEquip2->setText("Unequip");
-        else
+#ifdef Q_WS_MAEMO_5
+            ui->pbnEquip2->setFixedWidth(120);
+#endif
+        }else{
             ui->pbnEquip2->setText("Equip");
+#ifdef Q_WS_MAEMO_5
+            ui->pbnEquip2->setFixedWidth(75);
+#endif
+        }
     }else{
         ui->lblWeapon2->setText("-");
     }
@@ -241,12 +257,7 @@ void StatusWindow::ShowData()
                 pbn->setObjectName(QString::number(index));
                 if (i->GetIsMeal())
                     pbn->setText("Eat");
-                else if(i->GetIsWeapon() || i->GetIsArmor()){
-                    if (i->GetIsEquipped())
-                        pbn->setText("Unequip");
-                    else
-                        pbn->setText("Equip");
-                }else
+                else
                     pbn->setText("Use");
                 pbn->setEnabled(i->IsUsable());
                 pbn->setMaximumSize(75, 50);
@@ -321,12 +332,22 @@ void StatusWindow::ShowData()
 
             if(i->GetIsWeapon() || i->GetIsArmor()){
                 QPushButton* pbn = new QPushButton(this);
+                pbn->setEnabled(i->GetCanBeEquipped());
                 pbn->setObjectName(QString::number(index));
-                if (i->GetIsEquipped())
+                if (i->GetIsEquipped()){
                     pbn->setText("Unequip");
-                else
+#ifdef Q_WS_MAEMO_5
+                    pbn->setMaximumSize(120, 50);
+#endif
+                }else{
                     pbn->setText("Equip");
+#ifdef Q_WS_MAEMO_5
+                    pbn->setMaximumSize(75, 50);
+#endif
+                }
+#ifndef Q_WS_MAEMO_5
                 pbn->setMaximumSize(75, 50);
+#endif
                 connect(pbn, SIGNAL(clicked()), this, SLOT(EquipItemSlot()));
                 ui->laySpecialItems->addWidget(pbn, row, 2);
             }
